@@ -24,15 +24,19 @@ struct {
 
 void DEF_videoandsound ()
 {
+    int diff = 0;
+
     // Video Defaults
-	
-    CHECKBUTTON_fullscreen		    -> value (0);
-    ROUNDBUTTON_640x480			    -> value (1);
-    ROUNDBUTTON_800x600			    -> value (0);
+
+    diff += CHECKBUTTON_fullscreen		    -> value (0);
+    diff += CHOICE_windowsize                       -> value (0); // WS_640x480
 
     // Sound Defaults
-    
-    CHECKBUTTON_soundeffects		    -> value (1);
+   
+    diff += CHECKBUTTON_soundeffects		    -> value (1);
+
+    if (diff)
+      BUTTON_apply->activate();
 }
 
 bool CHKBUT_fulls_isdef ()
@@ -43,25 +47,23 @@ bool CHKBUT_fulls_isdef ()
        return 0;
 }
 
-bool RNDBUT_scrnsz_isdef()
-{
-    if (ROUNDBUTTON_640x480->value() == 1)
-       return 1;
-    else
-       return 0;
-}
-
 void DEF_mouseandkeyboard ()
 {
+    int diff = 0;
+
     // Mouse Defaults
-    
-    CHECKBUTTON_fancycursorshapes	    -> value (1);
-    CHECKBUTTON_grabmousepointer	    -> value (0);
-    CHECKBUTTON_mousewheelsupport	    -> value (1);
+
+    diff += CHECKBUTTON_fancycursorshapes	    -> value (1);
+    diff += CHECKBUTTON_grabmousepointer	    -> value (0);
+    diff += CHECKBUTTON_mousewheelsupport	    -> value (1);
+    diff += CHECKBUTTON_nobuttondistinction	    -> value (0);
 	
     // Keyboard Defaults
     
-    CHECKBUTTON_enablekbd		    -> value (1);
+    diff += CHECKBUTTON_enablekbd		    -> value (1);
+
+    if (diff)
+      BUTTON_apply->activate();
 }
 
 bool CHKBUT_fancycursors_isdef ()
@@ -98,17 +100,22 @@ bool CHKBUT_enablekb_isdef ()
 
 void DEF_simplification ()
 {
+    int diff = 0;
+
     // Interface Simplification Defaults
 
-    CHECKBUTTON_disableshaperotation	    -> value (0);
-    CHECKBUTTON_simpleshapeoutlines	    -> value (0);
-    CHECKBUTTON_showuppercasetextonly	    -> value (0);
+    diff += CHECKBUTTON_disableshaperotation	    -> value (0);
+    diff += CHECKBUTTON_simpleshapeoutlines	    -> value (0);
+    diff += CHECKBUTTON_showuppercasetextonly	    -> value (0);
 
     // Control Simplification Defaults
     
-    CHECKBUTTON_disablequitbutton	    -> value (0);
-    CHECKBUTTON_disablestampstool	    -> value (0);
-    CHECKBUTTON_disablestampcontrols	    -> value (0);
+    diff += CHECKBUTTON_disablequitbutton	    -> value (0);
+    diff += CHECKBUTTON_disablestampstool	    -> value (0);
+    diff += CHECKBUTTON_disablestampcontrols	    -> value (0);
+
+    if (diff)
+      BUTTON_apply->activate();
 }
 
 bool CHKBUT_norots_isdef ()
@@ -145,9 +152,15 @@ bool CHKBUT_disablequit_isdef ()
 
 void DEF_locale ()
 {
+    int diff = 0;
+
     // Locale Defaults
 	
-    CHECKBUTTON_mirrorstamps		    -> value (0);
+    diff += CHECKBUTTON_mirrorstamps		    -> value (0);
+    diff += CHECKBUTTON_loadsystemfonts		    -> value (1);
+
+    if (diff)
+      BUTTON_apply->activate();
 }
 
 bool CHKBUT_mirstamps_isdef()
@@ -161,15 +174,31 @@ bool CHKBUT_mirstamps_isdef()
 
 void DEF_printing ()
 {
+    int diff = 0;
+
     // Printing Perm. Defaults
 
-    CHECKBUTTON_allowprinting		    -> value (1);
-    VALUEINPUT_printdelay		    -> value (0);
+    diff += CHECKBUTTON_allowprinting		    -> value (1);
+    diff += VALUEINPUT_printdelay		    -> value (0);
+
+    // Print Dialog
+
+    diff += ROUNDBUTTON_printdialogmod    -> value (1);
+    diff += ROUNDBUTTON_printdialogalways -> value (0);
+    diff += ROUNDBUTTON_printdialognever  -> value (0);
 
     // Print Cmd. Defaults
 
-    CHECKBUTTON_usealtprintcmd		    -> value (0);
-    TEXTINPUT_printcmd			    -> deactivate ();
+    diff += CHECKBUTTON_usealtprintcmd		    -> value (0);
+    TEXTINPUT_printcmd				    -> deactivate ();
+
+    // Print Dialog Cmd. Defaults
+
+    diff += CHECKBUTTON_usealtprintdia		    -> value (0);
+    TEXTINPUT_printdia				    -> deactivate ();
+
+    if (diff)
+      BUTTON_apply->activate();
 }
 
 bool CHKBUT_allowprint_isdef()
@@ -191,17 +220,22 @@ bool VALINP_printdel_isdef()
 
 void DEF_saving ()
 {
+    int diff = 0;
+
     // Saving Over Defaults
 
-    ROUNDBUTTON_askbeforeoverwriting	    -> value (1);
-    ROUNDBUTTON_alwaysoverwriteolderversion -> value (0);
-    ROUNDBUTTON_alwayssavenewpicture	    -> value (0);
+    diff += ROUNDBUTTON_askbeforeoverwriting	    -> value (1);
+    diff += ROUNDBUTTON_alwaysoverwriteolderversion -> value (0);
+    diff += ROUNDBUTTON_alwayssavenewpicture	    -> value (0);
 
     // Save Directory Defaults
 
-    CHECKBUTTON_usealternatesavedir	    -> value (0);
-    FILEINPUT_alternatesavedir		    -> deactivate ();
-    BUTTON_browsealternatesavedir	    -> deactivate ();
+    diff += CHECKBUTTON_usealternatesavedir	    -> value (0);
+    FILEINPUT_alternatesavedir			    -> deactivate ();
+    BUTTON_browsealternatesavedir		    -> deactivate ();
+
+    if (diff)
+      BUTTON_apply->activate();
 }
 
 bool RNDBUT_askoverwrite_isdef()
